==> igniteui-react-charts-16.6.8.tgz: package/ES2015/MoneyFlowIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { MoneyFlowIndexIndicatorStrategy } from "./MoneyFlowIndexIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core/ES2015/type";
/**
 * @hidden
 */
export class MoneyFlowIndexIndicator extends StrategyBasedIndicator {
    constructor() {
        super();
        this.pd = 1;
    }
    get_p5() {
        return new MoneyFlowIndexIndicatorStrategy();
    }
    get p5() {
        return this.get_p5();
    }
    get_qi() {
        return MoneyFlowIndexIndicator.$;
    }
    get qi() {
        return this.get_qi();
    }
    get qq() {
        return typeGetValue(this.c(MoneyFlowIndexIndicator.qr));
    }
    set qq(a) {
        this.h(MoneyFlowIndexIndicator.qr, a);
    }
    qb() {
        return this.qq;
    }
    qk(a) {
        this.qq = a;
    }
}
MoneyFlowIndexIndicator.$t = markType(MoneyFlowIndexIndicator, 'MoneyFlowIndexIndicator', StrategyBasedIndicator.$);
MoneyFlowIndexIndicator.qr = StrategyBasedIndicator.qn(14, MoneyFlowIndexIndicator.$);

==> igniteui-react-charts-16.11.1.tgz: package/ES2015/MoneyFlowIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { MoneyFlowIndexIndicatorStrategy } from "./MoneyFlowIndexIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core/ES2015/type";
/**
 * @hidden
 */
export class MoneyFlowIndexIndicator extends StrategyBasedIndicator {
    constructor() {
        super();
        this.pk = 1;
    }
    get_qc() {
        return new MoneyFlowIndexIndicatorStrategy();
    }
    get qc() {
        return this.get_qc();
    }
    get_qp() {
        return MoneyFlowIndexIndicator.$;
    }
    get qp() {
        return this.get_qp();
    }
    get qx() {
        return typeGetValue(this.c(MoneyFlowIndexIndicator.qy));
    }
    set qx(a) {
        this.h(MoneyFlowIndexIndicator.qy, a);
    }
    qi() {
        return this.qx;
    }
    qr(a) {
        this.qx = a;
    }
}
MoneyFlowIndexIndicator.$t = markType(MoneyFlowIndexIndicator, 'MoneyFlowIndexIndicator', StrategyBasedIndicator.$);
MoneyFlowIndexIndicator.qy = StrategyBasedIndicator.qu(14, MoneyFlowIndexIndicator.$);
